aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorGlen Mazza <gmazza@apache.org>2004-01-05 22:13:19 +0000
committerGlen Mazza <gmazza@apache.org>2004-01-05 22:13:19 +0000
commit3ec512a82e22dab1b9b844d6f4284bd8072025d0 (patch)
treedb77d3ab3bdd40f229064dea1549fadb4c46a5a4
parentf9bf0d71114e79223b093f383e7cfe3db3ee4588 (diff)
downloadxmlgraphics-fop-3ec512a82e22dab1b9b844d6f4284bd8072025d0.tar.gz
xmlgraphics-fop-3ec512a82e22dab1b9b844d6f4284bd8072025d0.zip
Switch from strings->ints in Property.setSubprop() (from Finn Bock).
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@197142 13f79535-47bb-0310-9956-ffa450edef68
-rw-r--r--src/java/org/apache/fop/fo/Property.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/java/org/apache/fop/fo/Property.java b/src/java/org/apache/fop/fo/Property.java
index ed01900c3..0fd2ba732 100644
--- a/src/java/org/apache/fop/fo/Property.java
+++ b/src/java/org/apache/fop/fo/Property.java
@@ -192,7 +192,8 @@ public class Property {
if (spMaker != null) {
Property p = spMaker.make(propertyList, value, fo);
if (p != null) {
- return setSubprop(baseProp, partName, p);
+ int partId = FOPropertyMapping.getSubPropertyId(partName);
+ return setSubprop(baseProp, partId, p);
}
} else {
//getLogger().error("compound property component "
@@ -210,12 +211,12 @@ public class Property {
* compound properties.
* @param baseProp The Property object representing the compound property,
* such as SpaceProperty.
* @param partName The name of the component whose value is specified.
* @param subProp A Property object holding the specified value of the
* component to be set.
* @return The modified compound property object.
*/
- protected Property setSubprop(Property baseProp, String partName,
+ protected Property setSubprop(Property baseProp, int partId,
Property subProp) {
return baseProp;
}
@@ -210,12 +211,12 @@ public class Property {
* @param baseProp The Property object representing the compound property,
* such as SpaceProperty.
- * @param partName The name of the component whose value is specified.
+ * @param partId The ID of the component whose value is specified.
* @param subProp A Property object holding the specified value of the
* component to be set.